@@ -149,7 +149,7 @@ test_that("Testing bootMice works", {
       library(mice)
       set.seed(564764)
       #bootstrap 10 times and impute each twice
-      imps <- bootMice(ex_linquad, nBoot=10, nImp=2)
+      imps <- bootMice(linquad, nBoot=10, nImp=2)
     }
   }, "It is recommended to use at least 200 bootstraps.")
 })
@@ -161,9 +161,9 @@ test_that("Testing bootSmcfcs works", {
       set.seed(564764)
       #bootstrap twice and impute each twice
       #in practice you should bootstrap many more times, e.g. at least 200
-      imps <- bootSmcfcs(ex_linquad, nBoot=2, nImp=2,
-                         smtype="lm", smformula="y~z+x+xsq",
-                         method=c("","","norm","x^2",""))
+      imps <- bootSmcfcs(linquad, nBoot=2, nImp=2,
+                         smtype="lm", smformula="y~z+x+I(x^2)",
+                         method=c("","","norm",""))
     }
   }, "It is recommended to use at least 200 bootstraps.")
 })
